﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using WpfApplication2.Models;

namespace WpfApplication2.ViewModels
{
    public class MainWindowsViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;
        protected void RaisePropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        ObservableCollection<Person> people;
        public ObservableCollection<Person> People
        {
            get { return people; }
            set
            {
                people = value;
                RaisePropertyChanged("People");
            }
        }

        private Person currentPerson;
        public Person CurrentPerson
        {
            get { return currentPerson; }
            set
            {
                currentPerson = value;
                RaisePropertyChanged("CurrentPerson");
            }
        }

        public MainWindowsViewModel()
        {
            People = new ObservableCollection<Person>
            {
                new Person{ Id=0 , Age=11 , Name="kaki104" , Sex=true},
                new Person{ Id=1 , Age=22 , Name="kakao" , Sex=false},
                new Person{ Id=2 , Age=33 , Name="kass" , Sex=true},
                new Person{ Id=3 , Age=44 , Name="kameo" , Sex=false},
                new Person{ Id=4 , Age=55 , Name="keroro" , Sex=true}
            };
            CurrentPerson = People.FirstOrDefault();
        }

        ICommand addCommand;
        public ICommand AddCommand
        {
            get
            {
                if (addCommand == null)
                {
                    addCommand = new DelegateCommand(obj =>
                    {
                        CurrentPerson = new Person();
                        CurrentPerson.Id = People.Max(p => p.Id) + 1;
                        People.Add(CurrentPerson);
                    });
                }
                return addCommand;
            }
        }

        ICommand removeCommand;
        public ICommand RemoveCommand
        {
            get
            {
                if (removeCommand == null)
                {
                    removeCommand = new DelegateCommand(obj =>
                    {

                        if (CurrentPerson != null && People.Count(p => p.Id == CurrentPerson.Id) > 0)
                        {
                            People.Remove(CurrentPerson);
                        }
                    });
                }
                return removeCommand;
            }
        }

        ICommand selectChangedCommand;
        public ICommand SelectChangedCommand
        {
            get
            {
                if (selectChangedCommand == null)
                {
                    selectChangedCommand = new DelegateCommand(obj =>
                    {
                        var person = obj as Person;
                        if (person != null && People.Count(p => p.Id == person.Id) > 0)
                        {
                            CurrentPerson = person;
                        }
                    });
                }
                return selectChangedCommand;
            }
        }

    }
}
